@@ -609,7 +609,11 @@ function count_rows($condition='') {
 				$stmt = $this->pdo->prepare($sql);
 				if($stmt->execute()) {
 					$table_values = $stmt->fetchAll(PDO::FETCH_ASSOC);
-					$num = $table_values[0]['count(id)'];
+					if($table_values[0]['count']) {
+						$num = $table_values[0]['count'];
+					} else {
+						$num = $table_values[0]['count(id)'];
+					}
 				}
 			} else {
 				switch($this->__db_system_type) {
@@ -649,7 +653,16 @@ function bind_pager(array $params=array()) {
 	}
 	$this->__pager_params['perPage'] = $per_page;
 	$this->__pager_params['totalItems'] = $total_items;
-	$this->__pager = Pager::factory($this->__pager_params);
+	if(substr($_SERVER['PHP_SELF'],-9)=='index.php') {
+		$tmp = $_SERVER['PHP_SELF'];
+		$_SERVER['PHP_SELF'] = $_SERVER['REQUEST_URI'];
+		$this->__pager = Pager::factory($this->__pager_params);
+		$_SERVER['PHP_SELF'] = $tmp;
+	} else {
+		$this->__pager = Pager::factory($this->__pager_params);
+	}
+
+	
 }
 
 function select_table_with_pager($condition='',$fields='*') {
