@@ -404,20 +404,25 @@ public function new_component($file_path) {
  *
  *	@access	public
  *	@param	string $formName Form's name.
- *	@param	string $method (optional)Form's method defaults to 'POST'
- *	@param	string $action (optional)Form's action
- *	@param	string $target (optional)Form's target defaults to '_self'
- *	@param	mixed $attributes (optional)Extra attributes for <form> tag
- *	@param	bool $trackSubmit (optional)Whether to track if the form was submitted by adding a special hidden field
+ *	@param	array $params From's option
+ *		string $params['method'] (optional)Form's method defaults to 'POST'
+ *		string $params['action (optional)Form's action
+ *		string $params['target (optional)Form's target defaults to '_self'
+ *		array $params['attributes (optional)Extra attributes for <form> tag
  *	@return	object DataView class object that override PEAR::HTML_QuickForm
  */
-public function new_form_obj($name='',$method='post',$action='',$target='_self',$attribute='') {
+public function new_form_obj($name='',$params=array()) {
 	if(!$name) {
 		$name = 'form'.$this->quick_form_no;
 		$this->quick_form_no++;
 	}
+	$method = $params['method'] ? $params['method'] : 'post';
+	$action = $params['action'] ? $params['action'] : '';
 	if(!$action and $this->force_post_action) $action = $this->force_post_action;
-	$form = new DataView($name,$method,$action,$target,$attribute);
+	$target = $params['target'] ? $params['target'] : '_self';
+	$attributes = $params['attributes'] ? $params['attributes'] : null;
+	$trackSubmit = $params['trackSubmit'] ? $params['trackSubmit'] : false;
+	$form = new DataView($name,$method,$action,$target,$attribute,$trackSubmit);
 	$form->__page_obj = $this;
 	return $form;
 }
@@ -514,10 +519,12 @@ public function assign_form($name,$form) {
 	$renderer = new HTML_QuickForm_Renderer_ArraySmarty($this);
 	$form->accept($renderer);
 	$this->form_result = $renderer->toArray();
-	foreach($form->data_view as $column=>$attributes) {
-		if($attributes['reference']) {
-			$this->form_result[$column]['html'] = 
-				$this->get_value_from_table($this->form_result[$column]['value'],$attributes['reference']);
+	if(is_array($form->data_view) and count($form->data_view)>0) {
+		foreach($form->data_view as $column=>$attributes) {
+			if($attributes['reference']) {
+				$this->form_result[$column]['html'] = 
+					$this->get_value_from_table($this->form_result[$column]['value'],$attributes['reference']);
+			}
 		}
 	}
 	if(count($this->form_result['errors'])) {
@@ -569,20 +576,25 @@ public function set_form_error($message) {
  *
  *	@access	public
  *	@param	string $formName Form's name.
- *	@param	string $method (optional)Form's method defaults to 'POST'
- *	@param	string $action (optional)Form's action
- *	@param	string $target (optional)Form's target defaults to '_self'
- *	@param	mixed $attributes (optional)Extra attributes for <form> tag
- *	@param	bool $trackSubmit (optional)Whether to track if the form was submitted by adding a special hidden field
- *	@return	object DataView class object that override PEAR::HTML_QuickForm
+ *	@param	array $params From's option
+ *		string $params['method'] (optional)Form's method defaults to 'POST'
+ *		string $params['action (optional)Form's action
+ *		string $params['target (optional)Form's target defaults to '_self'
+ *		array $params['attributes (optional)Extra attributes for <form> tag
+ *	@return	object DataSet class object that override PEAR::HTML_QuickForm
  */
-public function new_data_obj($name='',$method='post',$action='',$target='_self',$attribute='') {
+public function new_data_obj($name='',$params=array()) {
 	if(!$name) {
 		$name = 'form'.$this->quick_form_no;
 		$this->quick_form_no++;
-	 }
-	 if(!$action and $this->force_post_action) $action = $this->force_post_action;
-	$form = new DataSet($name,$method,$action,$target,$attribute);
+	}
+	$method = $params['method'] ? $params['method'] : 'post';
+	$action = $params['action'] ? $params['action'] : '';
+	if(!$action and $this->force_post_action) $action = $this->force_post_action;
+	$target = $params['target'] ? $params['target'] : '_self';
+	$attributes = $params['attributes'] ? $params['attributes'] : null;
+	$trackSubmit = $params['trackSubmit'] ? $params['trackSubmit'] : false;
+	$form = new DataSet($name,$method,$action,$target,$attributes,$trackSubmit);
 	$form->__page_obj = $this;
 	$form->memcached = $this->memcached;
 	$form->memcache_compress = $this->memcache_compress;
@@ -612,11 +624,15 @@ public function get_row_from_table($data_set_name,$condition) {
  *	Quick build DataSet object and bind data_view and data_set
  *
  *	@access	public
+ *	@param	array $params From's option
+ *		string $params['method'] (optional)Form's method defaults to 'POST'
+ *		string $params['action (optional)Form's action
+ *		string $params['target (optional)Form's target defaults to '_self'
+ *		string $params['attributes (optional)Extra attributes for <form> tag
  *	@param	string $set_name DataSet form's name and data_view file's name and data_set file's name.
  *	@return	object DataSet object.
  */
-public function new_data_set($set_name,$cache=false) {
-
+public function new_data_set($set_name,$params=array(),$cache=false) {
 	if($cache and $this->memcached) {
 		$DATA_SET_CACHE = $this->memcache->get('DATA_SET_'.$set_name);
 	} elseif($cache and function_exists(apc_fetch)) {
@@ -626,7 +642,7 @@ public function new_data_set($set_name,$cache=false) {
 		$data_set = $DATA_SET_CACHE;
 		$this->memcache_use .= $set_name." : get from cache.\n";
 	} else {
-		$data_set = $this->new_data_obj($set_name);
+		$data_set = $this->new_data_obj($set_name,$params);
 		$data_set->bind_data_view($set_name.'.view.conf');
 		$data_set->bind_data_set($set_name.'.set.conf');	
 		$this->memcache_use .= $set_name." : generated.\n";
